# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"wrapper": "00_wrapper.ipynb",
         "survey": "01_survey.ipynb",
         "evaluater": "02_evaluateFromSearch.ipynb"}

modules = ["wrapper.py",
           "survey.py",
           "evaluate.py",
           "evaluateSearch.py",
           "None.py"]

doc_url = "https://brockmanmatt.github.io/OpenAISurveyWrapper/"

git_url = "https://github.com/brockmanmatt/OpenAISurveyWrapper/tree/master/"

def custom_doc_links(name): return None
